About Weblate
=============

Project goals
-------------

Web-based continuous localization tool with tight :ref:`vcs` supporting a wide range of
:ref:`formats`, making it easy for translators to contribute.

Project name
------------

"Weblate" is a portmanteau of the words "web" and "translate".

Project website
---------------

The landing page is <https://weblate.org/> and a cloud hosted service at
<https://hosted.weblate.org/>. This documentation can be found on
<https://docs.weblate.org/>.

Project logos
-------------

The project logos and other graphics is available in
<https://github.com/WeblateOrg/graphics/> repository.

Leadership
----------

This project is maintained by Michal Čihař <michal@cihar.com>.

Authors
-------

Weblate was started by Michal Čihař <michal@cihar.com>. Since its inception in
2012, thousands of people have contributed.
